@@ -6,6 +6,7 @@ import pandas as pd
 
 import copy
 import time
+import json
 
 import matplotlib as mpl
 import matplotlib.pyplot as plt
@@ -556,9 +557,9 @@ class ANN():
         end_time = time.time()
         
         t = end_time - start_time
-        h = round(t//3600, 0)
-        m = round((t-(3600*h))//60, 0)
-        s = round(t-(3600*h)-(60*m), 0)
+        h = int(round(t//3600, 0))
+        m = int(round((t-(3600*h))//60, 0))
+        s = int(round(t-(3600*h)-(60*m), 0))
         
         if display:
             print(str(h) + " hour " + str(m) + " min " +  str(s)+ " sec taken")
@@ -905,7 +906,7 @@ def visualize_fanio(fan_ins, fan_outs):
     fig1.suptitle("Actiavation Dists")
     fig2.suptitle("Fan Out Dists")
 
-    for i in range(len(fis)):
+    for i in range(len(fan_ins)):
 
         fi_axes[i].hist(fan_ins[i+1].reshape(1, -1)[0], bins=20, color="#00ACCD")
         fi_axes[i].set_xlabel('Layer' + str(i+1))
